<?php

namespace App\Controller;

use App\Repository\InterventionRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/calendrier')]
class CalendrierController extends AbstractController
{
    #[Route('/chauffagiste', name: 'app_calendrier_indexChauffagiste')]
    public function indexChauffagiste(InterventionRepository $interventionRepository): Response
    {
        // Vérification : seul le chauffagiste connecté peut voir son propre calendrier
        $this->denyAccessUnlessGranted('ROLE_CHAUFFAGISTE');

        // Récupérer les interventions du chauffagiste connecté
        $interventions = $interventionRepository->findByUser($this->getUser());

        // Préparer les événements pour FullCalendar
        $events = [];
        foreach ($interventions as $intervention) {
            $events[] = [
                'title' => $intervention->getTitle(),
                'start' => $intervention->getStartDate()->format('Y-m-d H:i:s'),
                'end' => $intervention->getEndDate()->format('Y-m-d H:i:s'),
                'description' => $intervention->getDescription(),
            ];
        }

        // Passer les événements à la vue
        return $this->render('calendrier/indexChauffagiste.html.twig', [
            'events' => json_encode($events),
        ]);
    }

    #[Route('/secretaire', name: 'app_calendrier_indexSecretaire')]
    public function indexSecretaire(InterventionRepository $interventionRepository): Response
    {
        // Vérification : seul le secrétaire peut accéder à ce calendrier
        $this->denyAccessUnlessGranted('ROLE_SECRETAIRE');

        // Récupérer toutes les interventions de tous les chauffagistes
        $interventions = $interventionRepository->findAll();

        // Préparer les événements pour FullCalendar
        $events = [];
        foreach ($interventions as $intervention) {
            $events[] = [
                'title' => $intervention->getTitle(),
                'start' => $intervention->getStartDate()->format('Y-m-d H:i:s'),
                'end' => $intervention->getEndDate()->format('Y-m-d H:i:s'),
                'description' => $intervention->getDescription(),
            ];
        }

        // Passer les événements à la vue
        return $this->render('calendrier/indexSecretaire.html.twig', [
            'events' => json_encode($events),
        ]);
    }

    #[Route('/admin', name: 'app_calendrier_index')]
    public function indexAdmin(InterventionRepository $interventionRepository): Response
    {
        // Vérification : seul un admin peut accéder à ce calendrier
        $this->denyAccessUnlessGranted('ROLE_ADMIN');

        // Récupérer toutes les interventions de tous les chauffagistes
        $interventions = $interventionRepository->findAll();

        // Préparer les événements pour FullCalendar
        $events = [];
        foreach ($interventions as $intervention) {
            $events[] = [
                'title' => $intervention->getTitle(),
                'start' => $intervention->getStartDate()->format('Y-m-d H:i:s'),
                'end' => $intervention->getEndDate()->format('Y-m-d H:i:s'),
                'description' => $intervention->getDescription(),
            ];
        }

        // Passer les événements à la vue
        return $this->render('calendrier/index.html.twig', [
            'events' => json_encode($events),
        ]);
    }
}
